/*
 *
 *  Copyright (c) 2010 Zagaia (INdT - Instituto Nokia de Tecnologia/
 *       FUCAPI - Fundação Centro de Análise, Pesquisa e Inovação Tecnológica)
 *
 *  This file is part of TweeGo.
 *
 *  TweeGo is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  TweeGo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with TweeGo. If not, see <http://www.gnu.org/licenses/>
 *
 */

#include "twitterapplicationitem.h"

/*!
    \brief TwitterApplicationItem contructor.

    Initializes the TwitterApplicationItem.
*/
TwitterApplicationItem::TwitterApplicationItem(QGraphicsWidget *parent)
        : QGraphicsWidget(parent),
          _loader(NULL)
{}

void TwitterApplicationItem::loaderExitAnimation(void)
{
    if(_loader != NULL)
        _deleteLoader();
}

void TwitterApplicationItem::loaderEntryAnimation(void)
{
    if(_loader == NULL)
        _createLoader();

    _loader->setOpacity(1.0);
    _loader->startEntryAnimation();
}

void TwitterApplicationItem::_createLoader(void)
{
    _loader = new Loader(this);
    _loader->setZValue(3.0);
    _loader->setOpacity(0.0);

    connect(_loader, SIGNAL(finished()), this, SLOT(_deleteLoader()));
}

void TwitterApplicationItem::_deleteLoader(void)
{
    delete _loader;
    _loader = NULL;
}

QPointF TwitterApplicationItem::getLoaderPos(void)
{
    if(_loader == NULL)
        _createLoader();

    return _loader->getLoaderPos();
}

void TwitterApplicationItem::setLoaderPosition(int x, int y)
{
    QPointF pos = QPointF(x, y);
    setLoaderPosition(pos);
}

void TwitterApplicationItem::setLoaderPosition(QPointF pos)
{
    if(_loader == NULL)
        _createLoader();

    _loader->setLoaderPosition(pos);
}
